"""
Const values
"""
import sys

PY = sys.executable

CFG_VERSION_KEY = 'BREWBLOX_CFG_VERSION'
LIB_RELEASE_KEY = 'BREWBLOX_CTL_LIB_RELEASE'
RELEASE_KEY = 'BREWBLOX_RELEASE'
SKIP_CONFIRM_KEY = 'BREWBLOX_SKIP_CONFIRM'
DEBUG_KEY = 'BREWBLOX_DEBUG'

LOG_SHELL = 'SHELL'.ljust(10)
LOG_PYTHON = 'PYTHON'.ljust(10)
LOG_ENV = 'ENV'.ljust(10)
LOG_COMPOSE = 'COMPOSE'.ljust(10)
LOG_INFO = 'INFO'.ljust(10)
LOG_WARN = 'WARN'.ljust(10)
LOG_ERR = 'ERROR'.ljust(10)
